# `ml-edu`

[![Unittests](https://github.com/google/ml-edu/actions/workflows/pytest_and_autopublish.yml/badge.svg)](https://github.com/google/ml-edu/actions/workflows/pytest_and_autopublish.yml)
[![PyPI version](https://badge.fury.io/py/ml-edu.svg)](https://badge.fury.io/py/ml-edu)

This repository contains Python utilities for performing machine learning tasks, optimized for use in [Google Colab](https://colab.research.google.com/).
